<?php
/**
 * The template for displaying the Featured Content
 *
 * @package Catch Themes
 * @subpackage Clean Journal Pro
 * @since Clean Journal 1.0
 */

if ( ! defined( 'CLEAN_JOURNAL_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


if( !function_exists( 'clean_journal_featured_content_display' ) ) :
/**
* Add Featured content.
*
* @uses action hook clean_journal_before_content.
*
* @since Clean Journal 1.0
*/
function clean_journal_featured_content_display() {
	//clean_journal_flush_transients();
	global $post, $wp_query;

	// get data value from options
	$options 		= clean_journal_get_theme_options();
	$enablecontent 	= $options['featured_content_option'];
	$contentselect 	= $options['featured_content_type'];

	// Front page displays in Reading Settings
	$page_on_front 	= get_option('page_on_front') ;
	$page_for_posts = get_option('page_for_posts');


	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();
	if ( 'entire-site' == $enablecontent  || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enablecontent  ) ) {
		if ( 'featured-widget-content' == $contentselect  ) {
			get_sidebar( 'featured-widget-content' );
		}
		else {
			if ( ( !$clean_journal_featured_content = get_transient( 'clean_journal_featured_content' ) ) ) {
				$layouts 	 = $options['featured_content_layout'];
				$headline 	 = $options['featured_content_headline'];
				$subheadline = $options['featured_content_subheadline'];

				echo '<!-- refreshing cache -->';

				if ( !empty( $layouts ) ) {
					$classes = $layouts ;
				}

				if ( 'demo-featured-content' == $contentselect  ) {
					$classes 	.= ' demo-featured-content' ;
					$headline 		= __( 'Featured Content', 'clean-journal-pro' );
					$subheadline 	= __( 'Here you can showcase the x number of Featured Content. You can edit this Headline, Subheadline and Feaured Content from "Appearance -> Customize -> Featured Content Options".', 'clean-journal-pro' );
				}
				else if ( 'featured-post-content' == $contentselect  ) {
					$classes 	.= ' featured-post-content' ;
				}
				elseif ( 'featured-page-content' == $contentselect  ) {
					$classes .= ' featured-page-content' ;
				}
				elseif ( 'featured-category-content' == $contentselect  ) {
					$classes .= ' featured-category-content' ;
				}
				elseif ( 'featured-image-content' == $contentselect  ) {
					$classes .= ' featured-image-content' ;
				}

				$featured_content_position = $options['featured_content_position'];

				if ( '1' == $featured_content_position ) {
					$classes .= ' border-top' ;
				}

				$clean_journal_featured_content ='
					<section id="featured-content" class="' . $classes . '">
						<div class="wrapper">';
							if ( !empty( $headline ) || !empty( $subheadline ) ) {
								$clean_journal_featured_content .='<div class="featured-heading-wrap">';
									if ( !empty( $headline ) ) {
										$clean_journal_featured_content .='<h2 id="featured-heading" class="entry-title">' . wp_kses_post( $headline ) . '</h2>';
									}
									if ( !empty( $subheadline ) ) {
										$clean_journal_featured_content .='<p>' . wp_kses_post( $subheadline ) . '</p>';
									}
								$clean_journal_featured_content .='</div><!-- .featured-heading-wrap -->';
							}

							$clean_journal_featured_content .='
							<div class="featured-content-wrap">';
								// Select content
								if ( 'demo-featured-content' == $contentselect  && function_exists( 'clean_journal_demo_content' ) ) {
									$clean_journal_featured_content .= clean_journal_demo_content( $options );
								}
								else if ( 'featured-post-content' == $contentselect  && function_exists( 'clean_journal_post_content' ) ) {
									$clean_journal_featured_content .= clean_journal_post_content( $options );
								}
								elseif ( 'featured-page-content' == $contentselect  && function_exists( 'clean_journal_page_content' ) ) {
									$clean_journal_featured_content .= clean_journal_page_content( $options );
								}
								elseif ( 'featured-category-content' == $contentselect  && function_exists( 'clean_journal_category_content' ) ) {
									$clean_journal_featured_content .= clean_journal_category_content( $options );
								}
								elseif ( 'featured-image-content' == $contentselect  && function_exists( 'clean_journal_image_content' ) ) {
									$clean_journal_featured_content .= clean_journal_image_content( $options );
								}

				$clean_journal_featured_content .='
							</div><!-- .featured-content-wrap -->
						</div><!-- .wrapper -->
					</section><!-- #featured-content -->';
				set_transient( 'clean_journal_featured_content', $clean_journal_featured_content, 86940 );

			}
			echo $clean_journal_featured_content;
		}
	}
}
endif;


if ( ! function_exists( 'clean_journal_featured_content_display_position' ) ) :
/**
 * Homepage Featured Content Position
 *
 * @action clean_journal_content, clean_journal_after_secondary
 *
 * @since Clean Journal 1.0
 */
function clean_journal_featured_content_display_position() {
	// Getting data from Theme Options
	$options 		= clean_journal_get_theme_options();

	$featured_content_position = $options['featured_content_position'];

	if ( '1' != $featured_content_position ) {
		add_action( 'clean_journal_before_content', 'clean_journal_featured_content_display', 40 );
	} else {
		add_action( 'clean_journal_after_content', 'clean_journal_featured_content_display', 40 );
	}

}
endif; // clean_journal_featured_content_display_position
add_action( 'clean_journal_before', 'clean_journal_featured_content_display_position' );


if ( ! function_exists( 'clean_journal_demo_content' ) ) :
/**
 * This function to display featured posts content
 *
 * @get the data value from customizer options
 *
 * @since Clean Journal 1.0
 *
 */
function clean_journal_demo_content( $options ) {
	$clean_journal_demo_content = '
		<article id="featured-post-1" class="post hentry post-demo">
			<figure class="featured-content-image">
				<img alt="Travel Map" class="wp-post-image" src="'.trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/gallery/featured1-350x263.jpg" />
			</figure>
			<div class="entry-container">
				<header class="entry-header">
					<h2 class="entry-title">
						<a title="Travel Map" href="#">Travel Map</a>
					</h2>
				</header>
			</div><!-- .entry-container -->
		</article>

		<article id="featured-post-2" class="post hentry post-demo">
			<figure class="featured-content-image">
				<img alt="Volkswagen Camper" class="wp-post-image" src="'.trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/gallery/featured2-350x263.jpg" />
			</figure>
			<div class="entry-container">
				<header class="entry-header">
					<h2 class="entry-title">
						<a title="Volkswagen Camper" href="#">Volkswagen Camper</a>
					</h2>
				</header>
			</div><!-- .entry-container -->
		</article>

		<article id="featured-post-3" class="post hentry post-demo">
			<figure class="featured-content-image">
				<img alt="Best Beaches" class="wp-post-image" src="'.trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/gallery/featured3-350x263.jpg" />
			</figure>
			<div class="entry-container">
				<header class="entry-header">
					<h2 class="entry-title">
						<a title="Best Beaches" href="#">Best Beaches</a>
					</h2>
				</header>
			</div><!-- .entry-container -->
		</article>';

	if( 'layout-four' == $options['featured_content_layout'] || 'layout-two' == $options['featured_content_layout'] ) {
		$clean_journal_demo_content .= '
		<article id="featured-post-4" class="post hentry post-demo">
			<figure class="featured-content-image">
				<img alt="Santorini Island" class="wp-post-image" src="'.trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/gallery/featured4-350x263.jpg" />
			</figure>
			<div class="entry-container">
				<header class="entry-header">
					<h2 class="entry-title">
						<a title="Santorini Island" href="#">Santorini Island</a>
					</h2>
				</header>
			</div><!-- .entry-container -->
		</article>';
	}

	return $clean_journal_demo_content;
}
endif; // clean_journal_demo_content


if ( ! function_exists( 'clean_journal_post_content' ) ) :
/**
 * This function to display featured posts content
 *
 * @param $options: clean_journal_theme_options from customizer
 *
 * @since Clean Journal 1.0
 */
function clean_journal_post_content( $options ) {
	global $post;

	$quantity 		= $options['featured_content_number'];

	$number_of_post = 0; 		// for number of posts

	$post_list		= array();	// list of valid post ids

	$show_content	= $options['featured_content_show'];

	$clean_journal_post_content = '';

	//Get valid number of posts
	for( $i = 1; $i <= $quantity; $i++ ){
		if( isset ( $options['featured_content_post_' . $i] ) && $options['featured_content_post_' . $i] > 0 ){
			$number_of_post++;

			$post_list	=	array_merge( $post_list, array( $options['featured_content_post_' . $i] ) );
		}

	}

	if ( !empty( $post_list ) && $number_of_post > 0 ) {
		$loop = new WP_Query( array(
                    'posts_per_page' => $number_of_post,
                    'post__in'       => $post_list,
                    'orderby'        => 'post__in',
                    'ignore_sticky_posts' => 1 // ignore sticky posts
                ));

		$i=0;
		while ( $loop->have_posts()) : $loop->the_post(); $i++;
			$title_attribute = the_title_attribute( array( 'before' => __( 'Permalink to: ', 'clean-journal-pro' ), 'echo' => false ) );
			$excerpt = get_the_excerpt();
			$clean_journal_post_content .= '
				<article id="featured-post-' . $i . '" class="post hentry featured-post-content">';
				if ( has_post_thumbnail() ) {
					$clean_journal_post_content .= '
					<figure class="featured-homepage-image">
						<a href="' . esc_url( get_permalink() ) . '" title="'.the_title( '', '', false ).'">
						'. get_the_post_thumbnail( $post->ID, 'clean-journal-featured-content', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class' => 'pngfix' ) ) .'
						</a>
					</figure>';
				}
				else {
					$clean_journal_first_image = clean_journal_get_first_image( $post->ID, 'clean-journal-featured-content', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class' => 'pngfix' ) );

					if ( '' != $clean_journal_first_image ) {
						$clean_journal_post_content .= '
						<figure class="featured-homepage-image">
							<a href="' . esc_url( get_permalink() ) . '" title="'.the_title( '', '', false ).'">
								'. $clean_journal_first_image .'
							</a>
						</figure>';
					}
				}

				$clean_journal_post_content .= '
					<div class="entry-container">
						<header class="entry-header">
							<h2 class="entry-title">
								<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . the_title( '','', false ) . '</a>
							</h2>
						</header>';
						if ( 'excerpt' == $show_content ) {
							$clean_journal_post_content .= '<div class="entry-excerpt"><p>' . $excerpt . '</p></div><!-- .entry-excerpt -->';
						}
						elseif ( 'full-content' == $show_content ) {
							$content = apply_filters( 'the_content', get_the_content() );
							$content = str_replace( ']]>', ']]&gt;', $content );
							$clean_journal_post_content .= '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
						}
					$clean_journal_post_content .= '
					</div><!-- .entry-container -->
				</article><!-- .featured-post-'. $i .' -->';
		endwhile;

		wp_reset_postdata();
	}

	return $clean_journal_post_content;
}
endif; // clean_journal_post_content


if ( ! function_exists( 'clean_journal_page_content' ) ) :
/**
 * This function to display featured page content
 *
 * @param $options: clean_journal_theme_options from customizer
 *
 * @since Clean Journal 1.0
 */
function clean_journal_page_content( $options ) {
	global $post;

	$quantity 		= $options['featured_content_number'];

	$more_link_text	= $options['excerpt_more_text'];

	$show_content	= $options['featured_content_show'];

	$number_of_page = 0; 		// for number of pages

	$page_list		= array();	// list of valid pages ids

	$clean_journal_page_content 	= '';

	//Get valid pages
	for( $i = 1; $i <= $quantity; $i++ ){
		if( isset ( $options['featured_content_page_' . $i] ) && $options['featured_content_page_' . $i] > 0 ){
			$number_of_page++;

			$page_list	=	array_merge( $page_list, array( $options['featured_content_page_' . $i] ) );
		}

	}
	if ( !empty( $page_list ) && $number_of_page > 0 ) {
		$loop = new WP_Query( array(
                    'posts_per_page' 		=> $number_of_page,
                    'post__in'       		=> $page_list,
                    'orderby'        		=> 'post__in',
                    'post_type'				=> 'page',
                ));

		$i=0;
		while ( $loop->have_posts()) : $loop->the_post(); $i++;
			$title_attribute = the_title_attribute( array( 'before' => __( 'Permalink to: ', 'clean-journal-pro' ), 'echo' => false ) );

			$excerpt = get_the_excerpt();

			$clean_journal_page_content .= '
				<article id="featured-post-' . $i . '" class="post hentry featured-page-content">';
				if ( has_post_thumbnail() ) {
					$clean_journal_page_content .= '
					<figure class="featured-homepage-image">
						<a href="' . esc_url( get_permalink() ) . '" title="'.the_title( '', '', false ).'">
						'. get_the_post_thumbnail( $post->ID, 'clean-journal-featured-content', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class' => 'pngfix' ) ) .'
						</a>
					</figure>';
				}
				else {
					$clean_journal_first_image = clean_journal_get_first_image( $post->ID, 'clean-journal-featured-content', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class' => 'pngfix' ) );

					if ( '' != $clean_journal_first_image ) {
						$clean_journal_page_content .= '
						<figure class="featured-homepage-image">
							<a href="' . esc_url( get_permalink() ) . '" title="'.the_title( '', '', false ).'">
								'. $clean_journal_first_image .'
							</a>
						</figure>';
					}
				}

				$clean_journal_page_content .= '
					<div class="entry-container">
						<header class="entry-header">
							<h2 class="entry-title">
								<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . the_title( '','', false ) . '</a>
							</h2>
						</header>';
						if ( 'excerpt' == $show_content ) {
							$clean_journal_page_content .= '<div class="entry-excerpt"><p>' . $excerpt . '</p></div><!-- .entry-excerpt -->';
						}
						elseif ( 'full-content' == $show_content ) {
							$content = apply_filters( 'the_content', get_the_content() );
							$content = str_replace( ']]>', ']]&gt;', $content );
							$clean_journal_page_content .= '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
						}
					$clean_journal_page_content .= '
					</div><!-- .entry-container -->
				</article><!-- .featured-post-'. $i .' -->';
		endwhile;

		wp_reset_postdata();
	}

	return $clean_journal_page_content;
}
endif; // clean_journal_page_content


if ( ! function_exists( 'clean_journal_category_content' ) ) :
/**
 * This function to display featured category content
 *
 * @param $options: clean_journal_theme_options from customizer
 *
 * @since Clean Journal 1.0
 */
function clean_journal_category_content( $options ) {
	global $post;

	$quantity 		= $options['featured_content_number'];

	$more_link_text	= $options['excerpt_more_text'];

	$category_list	= $options['featured_content_select_category'];

	$show_content	= $options['featured_content_show'];

	$clean_journal_category_content = '';

	$loop = new WP_Query( array(
		'posts_per_page'		=> $quantity,
		'category__in'			=> $category_list,
		'ignore_sticky_posts' 	=> 1 // ignore sticky posts
	));

	$i=0;
	while ( $loop->have_posts()) : $loop->the_post(); $i++;
		$title_attribute = the_title_attribute( array( 'before' => __( 'Permalink to: ', 'clean-journal-pro' ), 'echo' => false ) );
		$excerpt = get_the_excerpt();
		$clean_journal_category_content .= '
			<article id="featured-post-' . $i . '" class="post hentry featured-category-content">';
			if ( has_post_thumbnail() ) {
				$clean_journal_category_content .= '
				<figure class="featured-homepage-image">
					<a href="' . esc_url( get_permalink() ) . '" title="'.the_title( '', '', false ).'">
					'. get_the_post_thumbnail( $post->ID, 'clean-journal-featured-content', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class' => 'pngfix' ) ) .'
					</a>
				</figure>';
			}
			else {
					$clean_journal_first_image = clean_journal_get_first_image( $post->ID, 'clean-journal-featured-content', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class' => 'pngfix' ) );

					if ( '' != $clean_journal_first_image ) {
						$clean_journal_category_content .= '
						<figure class="featured-homepage-image">
							<a href="' . esc_url( get_permalink() ) . '" title="'.the_title( '', '', false ).'">
								'. $clean_journal_first_image .'
							</a>
						</figure>';
					}
				}

			$clean_journal_category_content .= '
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . the_title( '','', false ) . '</a>
						</h2>
					</header>';
					if ( 'excerpt' == $show_content ) {
						$clean_journal_category_content .= '<div class="entry-excerpt"><p>' . $excerpt . '</p></div><!-- .entry-excerpt -->';
					}
					elseif ( 'full-content' == $show_content ) {
						$content = apply_filters( 'the_content', get_the_content() );
						$content = str_replace( ']]>', ']]&gt;', $content );
						$clean_journal_category_content .= '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
					}
				$clean_journal_category_content .= '
				</div><!-- .entry-container -->
			</article><!-- .featured-post-'. $i .' -->';
	endwhile;

	wp_reset_postdata();
	return $clean_journal_category_content;
}
endif; // clean_journal_category_content


if ( ! function_exists( 'clean_journal_image_content' ) ) :
/**
 * This function to display featured posts content
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 * @uses set_transient
 *
 * @since Clean Journal 1.0
 */
function clean_journal_image_content( $options ) {
	$quantity 		= $options['featured_content_number'];

	$more_link_text	= $options['excerpt_more_text'];

	$show_content	= $options['featured_content_show'];

	$clean_journal_image_content = '';

	for ( $i = 1; $i <= $quantity; $i++ ) {
		if ( !empty ( $options[ 'featured_content_target_' . $i ] ) ) {
			$target = '_blank';
		} else {
			$target = '_self';
		}

		//Checking Link
		if ( !empty ( $options[ 'featured_content_link_' . $i ] ) ) {
			//support qTranslate plugin
			if ( function_exists( 'qtrans_convertURL' ) ) {
				$link = qtrans_convertURL(  $options[ 'featured_content_link_' . $i ] );
			}
			else {
				$link =  $options[ 'featured_content_link_' . $i ];
			}
		}
		else {
			$link = '#';
		}

		//Checking Title
		if ( !empty ( $options[ 'featured_content_title_'. $i ] ) ) {
			$title =$options[ 'featured_content_title_'. $i ];
		}
		else {
			$title = '';
		}

		//Checking Content
		if ( !empty ( $options[ 'featured_content_content_'. $i ] ) ) {
			$content =$options[ 'featured_content_content_'. $i ];
		}
		else {
			$content = '';
		}

		$clean_journal_image_content .= '
		<article id="featured-post-'.$i.'" class="post hentry featured-image-content">';
			if ( !empty ( $options[ 'featured_content_image_' . $i ] ) ) {
				$clean_journal_image_content .= '
				<figure class="featured-homepage-image">
					<a title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '" target="' . $target . '">
						<img src="'. $options[ 'featured_content_image_' . $i ] .'" class="wp-post-image" alt="' . esc_attr( $title ) . '" title="' . esc_attr( $title ) . '">
					</a>
				</figure>';
			}
			if ( '' != $title  || $content!='' ) {
				$clean_journal_image_content .= '
				<div class="entry-container">';
					if ( '' != $title  ) {
						$clean_journal_image_content .= '
						<header class="entry-header">
							<h2 class="entry-title">
								<a href="' . esc_url( $link ) . '" rel="bookmark" target="' . $target . '">' . $title . '</a>
							</h2>
						</header>';
					}
					if ( 'hide-content' != $show_content ) {
						if ( '' != $content )  {
							$clean_journal_image_content .= '
							<div class="entry-content"><p>
								' . $content . '
							</p></div>';
						}
					}
				$clean_journal_image_content .= '
				</div><!-- .entry-container -->';
			}
		$clean_journal_image_content .= '
		</article><!-- .featured-post-'.$i.' -->';

	}
	return $clean_journal_image_content;
}
endif; //clean_journal_image_content
