<?php
/**
 * The template for Managing Theme Structure
 *
 * @package Catch Themes
 * @subpackage Clean Journal Pro
 * @since Clean Journal 1.0
 */

if ( ! defined( 'CLEAN_JOURNAL_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


if ( ! function_exists( 'clean_journal_doctype' ) ) :
	/**
	 * Doctype Declaration
	 *
	 * @since Clean Journal 1.0
	 *
	 */
	function clean_journal_doctype() {
		?>
		<!DOCTYPE html>
		<html <?php language_attributes(); ?>>
		<?php
	}
endif;
add_action( 'clean_journal_doctype', 'clean_journal_doctype', 10 );


if ( ! function_exists( 'clean_journal_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Clean Journal 1.0
	 *
	 */
	function clean_journal_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php
		if ( is_singular() && pings_open() ) {
			echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
		}
	}
endif;
add_action( 'clean_journal_before_wp_head', 'clean_journal_head', 10 );


if ( ! function_exists( 'clean_journal_page_start' ) ) :
	/**
	 * Start div id #page
	 *
	 * @since Clean Journal 1.0
	 *
	 */
	function clean_journal_page_start() {
		?>
		<div id="page" class="hfeed site">
		<?php
	}
endif;
add_action( 'clean_journal_header', 'clean_journal_page_start', 10 );


if ( ! function_exists( 'clean_journal_header_top' ) ) :
	/**
	 * Header Top Area
	 *
	 * @since Clean Journal 1.0
	 *
	 */
	function clean_journal_header_top() {
		$options = clean_journal_get_theme_options();

		if ( !$options['disable_header_top'] ) {
			get_sidebar( 'header-top' );
		}
	}
endif;
add_action( 'clean_journal_header', 'clean_journal_header_top', 20 );


if ( ! function_exists( 'clean_journal_page_end' ) ) :
	/**
	 * End div id #page
	 *
	 * @since Clean Journal 1.0
	 *
	 */
	function clean_journal_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'clean_journal_footer', 'clean_journal_page_end', 200 );


if ( ! function_exists( 'clean_journal_header_start' ) ) :
	/**
	 * Start Header id #masthead and class .wrapper
	 *
	 * @since Clean Journal 1.0
	 *
	 */
	function clean_journal_header_start() {
		?>
		<header id="masthead" role="banner">
    		<div class="wrapper">
		<?php
	}
endif;
add_action( 'clean_journal_header', 'clean_journal_header_start', 40 );


if ( ! function_exists( 'clean_journal_header_end' ) ) :
	/**
	 * End Header id #masthead and class .wrapper
	 *
	 * @since Clean Journal 1.0
	 *
	 */
	function clean_journal_header_end() {
		?>
			</div><!-- .wrapper -->
		</header><!-- #masthead -->
		<?php
	}
endif;
add_action( 'clean_journal_header', 'clean_journal_header_end', 100 );


if ( ! function_exists( 'clean_journal_content_start' ) ) :
	/**
	 * Start div id #content and class .wrapper
	 *
	 * @since Clean Journal 1.0
	 *
	 */
	function clean_journal_content_start() {
		?>
		<div id="content" class="site-content">
			<div class="wrapper">
	<?php
	}
endif;
add_action('clean_journal_content', 'clean_journal_content_start', 10 );

if ( ! function_exists( 'clean_journal_content_end' ) ) :
	/**
	 * End div id #content and class .wrapper
	 *
	 * @since Clean Journal 1.0
	 */
	function clean_journal_content_end() {
		?>
			</div><!-- .wrapper -->
	    </div><!-- #content -->
		<?php
	}

endif;
add_action( 'clean_journal_after_content', 'clean_journal_content_end', 30 );


if ( ! function_exists( 'clean_journal_footer_content_start' ) ) :
/**
 * Start footer id #colophon
 *
 * @since Clean Journal 1.0
 */
function clean_journal_footer_content_start() {
	?>
	<footer id="colophon" class="site-footer" role="contentinfo">
    <?php
}
endif;
add_action('clean_journal_footer', 'clean_journal_footer_content_start', 30 );


if ( ! function_exists( 'clean_journal_footer_sidebar' ) ) :
/**
 * Footer Sidebar
 *
 * @since Clean Journal 1.0
 */
function clean_journal_footer_sidebar() {
	get_sidebar( 'footer' );
}
endif;
add_action( 'clean_journal_footer', 'clean_journal_footer_sidebar', 40 );


if ( ! function_exists( 'clean_journal_footer_content_end' ) ) :
/**
 * End footer id #colophon
 *
 * @since Clean Journal 1.0
 */
function clean_journal_footer_content_end() {
	?>
	</footer><!-- #colophon -->
	<?php
}
endif;
add_action( 'clean_journal_footer', 'clean_journal_footer_content_end', 110 );


if ( ! function_exists( 'clean_journal_header_right' ) ) :
/**
 * Header Right Sidebar
 *
 * @since Clean Journal 1.0
 */
function clean_journal_header_right() {
	$options = clean_journal_get_theme_options();

	//A sidebar in the Header Right
	if ( !$options['disable_header_right_sidebar'] ) {
		get_sidebar( 'header-right' );
	}
}
endif;
add_action( 'clean_journal_header', 'clean_journal_header_right', 70 );
